@@ -450,7 +450,7 @@ class nftables(object):
                                                 "hook": hook,
                                                 "prio": -300 + NFT_HOOK_OFFSET - 1,
                                                 "policy": "drop"}}})
-        if policy == "DROP":
+        elif policy == "DROP":
             rules.append({"add": {"table": {"family": "inet",
                                             "name": TABLE_NAME_POLICY}}})
             self.created_tables["inet"].append(TABLE_NAME_POLICY)
@@ -478,7 +478,7 @@ class nftables(object):
                                                    "name": TABLE_NAME_POLICY}}})
                 self.created_tables["inet"].remove(TABLE_NAME_POLICY)
         else:
-            FirewallError(UNKNOWN_ERROR, "not implemented")
+            raise FirewallError(UNKNOWN_ERROR, "not implemented")
 
         return rules
 
