@@ -45,7 +45,7 @@ class Watcher(object):
 
     def get_watches(self):
         return self._monitors.keys()
-        
+
     def has_watch(self, filename):
         return filename in self._monitors
 
@@ -61,7 +61,7 @@ class Watcher(object):
             self._blocked.remove(filename)
 
     def clear_timeouts(self):
-        for filename in self._timeouts.keys():
+        for filename in list(self._timeouts.keys()):
             GLib.source_remove(self._timeouts[filename])
             del self._timeouts[filename]
 
